@extends('cms::admin.layouts.app')
@php

    /**
 * @var \TDevAgency\Erp\Models\Order $Order
     * @var \Illuminate\Support\ViewErrorBag $errors
     *
    */

@endphp
@section('content')
    <form action="{{$formRoute}}" method="post" @submit="validateBeforeSubmit">

        @include('erp::components.save')
        @csrf
        @method($formMethod)
        <div class="row">
            <div class="col-md-7 col-xl-8">
                <div class="card">
                    <div class="card-header">
                        <h5>Информация о заказе
                        </h5></div>
                    <div class="card-body">
                        <div class="form-group">

                            @component('cms::components.select2')
                                @slot('key', 'order_status')
                                @slot('placeholder', 'Статус заказа')
                                @slot('value', old('order_status', $order->order_status?? null))
                                @slot('validate', 'required')
                                @slot('options', [
    \TDevAgency\Erp\Models\Order::STATUS_NEW => 'Новый',
    \TDevAgency\Erp\Models\Order::STATUS_INPROGRESS => 'Обработка',
    \TDevAgency\Erp\Models\Order::STATUS_ON_DELIVERY => 'Доставка',
    \TDevAgency\Erp\Models\Order::STATUS_DONE => 'Выполнен',
    \TDevAgency\Erp\Models\Order::STATUS_CLOSED => 'Закрыт',
    \TDevAgency\Erp\Models\Order::STATUS_REFUND => 'Возврат',
    \TDevAgency\Erp\Models\Order::STATUS_REJECT => 'Отменен',
])
                            @endcomponent
                            <div class="d-none">
                                @component('cms::components.input')
                                    @slot('key', 'total_price')
                                    @slot('type', 'number')
                                    @slot('placeholder', 'Общая цена заказа')
                                    @slot('value', old('total_price', $order->total_price?? null))
                                    @slot('attributes', ['step' => '0.01'])
                                @endcomponent
                            </div>
                            @component('cms::components.input')
                                @slot('key', 'products_price')
                                @slot('type', 'number')
                                @slot('placeholder', 'Общая цена за товары')
                                @slot('value', old('products_price', $order->products_price?? null))
                                @slot('attributes', ['step' => '0.01', 'readonly'])
                            @endcomponent

                            @component('cms::components.input')
                                @slot('key', 'order_delivery.track_number')
                                @slot('placeholder', 'Номер отслеживания')
                                @slot('value', old('order_delivery.track_number', $order->order_delivery->track_number?? null))
                            @endcomponent
                        </div>
                    </div>
                </div>
                <div class="card">
                    <div class="card-header">
                        <h5>Продукты в заказе
                        </h5></div>
                    <div class="card-body">
                        <order-items
                            :products='@json(old('order_items', $order->order_items?? []))'
                            products-query-url="{{route('cms.api.v1.products.query')}}"
                            delete-item-url="{{route('cms.api.v1.deliveries.items.delete')}}"
                        ></order-items>
                    </div>
                </div>
                <div class="card">
                    <div class="card-header">
                        <h5>Информация о клиенте</h5></div>
                    <div class="card-body">
                        <order-customer
                            :customer-data='@json(old('order_customer', $order->order_customer?? ['email' => null]))'
                            query-customer="{{route('cms.api.v1.customers.query')}}"
                        ></order-customer>
                    </div>
                </div>
            </div>
            <div class="col-md-5 col-xl-4">
                <div class="card">
                    <div class="card-header">
                        <h5>Доставка
                        </h5></div>
                    <div class="card-body">
                        <div class="custom-control custom-radio custom-control-inline">
                            <input type="radio" id="delivery_pickup" name="order_delivery[delivery_code]" value="pickup"
                                   @if(isset($order->order_delivery) && $order->order_delivery->delivery_code === 'pickup') checked @endif
                                   required class="custom-control-input">
                            <label class="custom-control-label" for="delivery_pickup">Самовывоз</label>
                        </div>
                        <nova-poshta-radio get-city-action="{{route('cms.api.v1.nova-poshta.cities')}}"
                                           @if(isset($order->order_delivery) && $order->order_delivery->delivery_code === 'nova_poshta')
                                           is-checked
                                           :selected='@json($order->order_delivery->delivery_data)'
                                           @endif
                                           get-wire-house-action="{{route('cms.api.v1.nova-poshta.wire-house')}}"></nova-poshta-radio>
                    </div>
                </div>
                <div class="card">
                    <div class="card-header">
                        <h5>Оплата
                        </h5></div>
                    <div class="card-body">
                        <div class="custom-control custom-radio custom-control-inline">
                            <input type="radio" id="delivery_cash" name="order_payment[payment_code]" value="cash"
                                   checked class="custom-control-input">
                            <label class="custom-control-label" for="delivery_cash">Наличными</label>
                        </div>
                    </div>
                </div>
                <div class="card">
                    <div class="card-header">
                        <h5>Комментарий к заказу
                        </h5></div>
                    <div class="card-body">

                        @component('cms::components.textarea')
                            @slot('key', 'order_comment')
                            @slot('placeholder', trans('erp::erp.order_comment'))
                            @slot('value', old('order_comment', $order->order_comment?? null))
                        @endcomponent
                    </div>
                </div>
            </div>
        </div>
    </form>
@endsection
@push('vue.components')
    <script src="{{mixErp('js/app.js')}}"></script>
@endpush

