<?php

namespace TDevAgency\Erp\Models;

use App\Helpers\NovaPoshtaHelper;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\Cache;
use Illuminate\Support\Facades\Session;
use TDevAgency\NovaPoshtaSdk\Api\AddressGeneral;
use TDevAgency\NovaPoshtaSdk\Facades\NovaPoshta;

class OrderDelivery extends Model
{
    protected $fillable = [
        'order_id',
        'delivery_code',
        'delivery_name',
        'delivery_status',
        'track_number',
        'delivery_price',
        'total_qty',
        'delivery_data',
    ];

    public function getDeliveryDataAttribute($value)
    {
        if ($value === null) {
            return null;
        }

        $data = unserialize(base64_decode($value));

        if (isset($data['city_ref']) && !is_null($data['city_ref'])) {
            $data['city_name'] = NovaPoshtaHelper::getCityName($data['city_ref']);
        }
        if (isset($data['wire_house_ref']) && !is_null($data['wire_house_ref'])) {

            $wirehouses = NovaPoshta::addressGeneralModel()->getWarehouses(
                ['CityRef' => $data['city_ref']],
                AddressGeneral::CATEGORY_BRANCH
            )->toArray();

            $key = array_search($data['wire_house_ref'], array_column($wirehouses, 'Ref'));

            $data['wire_house_name'] = $wirehouses[$key]['DescriptionRu'];
        }

        return $data;
    }
}
