<?php

namespace TDevAgency\Erp\Models;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasOne;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Kyslik\ColumnSortable\Sortable;
use TDevAgency\Cms\Traits\Filterable;
use TDevAgency\Cms\Traits\Searchable;
use TDevAgency\Erp\Interfaces\ErpModel;
use TDevAgency\Erp\Traits\Containerable;

class Product extends Model implements ErpModel
{
    use Sortable, Searchable, Filterable, Containerable;

    protected $fillable = [
        'sku',
        'container_id',
        'manufacturer_country',
        'product_name',
        'price',
        'special_price',
        'can_preorder',
        'can_gift',
        'guarantee_period',
        'manufacture_id',
        'product_weight',
        'product_width',
        'product_height',
        'product_length'
    ];
    protected $searchable = [
        'product_name',
        'sku'
    ];
    public $sortable = ['sku',
                        'updated_at',
                        'product_name',
                        'can_preorder',
                        'price'];
    public $sortableAs = ['qty'];

    public function getId()
    {
        return $this->getAttributeValue('sku');
    }

    public function getImage($size = null)
    {
        // TODO: Implement getImage() method.
    }

    public function getImageName(): string
    {
        // TODO: Implement getImageName() method.
    }

    public function getImageSizes(): array
    {
        return [

            '4k' => 3840,
            'xl' => 1920,
            'lg' => 1200,
            'md' => 768,
            'sm' => 576,
            'xs' => 150, // is thumb 150*150
        ];
    }

    public function getName(): string
    {
        return $this->getAttributeValue('product_name');
    }

    public function manufacture(): BelongsTo
    {
        return $this->belongsTo(Manufacture::class);
    }

    public function scopeContainer(Builder $query)
    {
        return $query->where('container_id', Auth::user()->container->id);
    }

    public function scopeQty(Builder $query)
    {
        return $query->select('products.*')->addSelect(DB::raw('0 as qty'));

        //        $sql = "((SELECT IF(SUM(qty) is not null, SUM(qty), 0) FROM deliveries where deliveries.product_id = products.id ) - (SELECT IF(SUM(qty) is not null, SUM(qty), 0) FROM customer_order_items where customer_order_items.product_id = products.id )) as qty";
        //        return $query->select('products.*')->addSelect(DB::raw($sql));
    }
}
